
# Class: problem


An object representing an error or problem encountered

URI: [http://example.org/sample/example1/Problem](http://example.org/sample/example1/Problem)


[![img](https://yuml.me/diagram/nofunky;dir:TB/class/[Problem&#124;description:string%20%3F]^-[DownloadProblem],[DownloadProblem])](https://yuml.me/diagram/nofunky;dir:TB/class/[Problem&#124;description:string%20%3F]^-[DownloadProblem],[DownloadProblem])

## Children

 * [DownloadProblem](DownloadProblem.md) - A problem in downloading a knowledge source

## Referenced by Class


## Attributes


### Own

 * [description](description.md)  <sub>0..1</sub>
     * Range: [String](types/String.md)
